@@ -29,7 +29,7 @@ __all__ = ["Registry",
 
 import os as _os
 from gi.repository import Atspi
-from gi.repository import GObject
+from gi.repository import GLib
 import time
 
 #------------------------------------------------------------------------------
@@ -50,9 +50,9 @@ class Registry(object):
         reference to the Accessibility.Registry singleton. Doing so is harmless and
         has no point.
 
-        @@ivar async: Should event dispatch to local listeners be decoupled from event
-                receiving from the registry?
-        @@type async: boolean
+        @@ivar asynchronous: Should event dispatch to local listeners be decoupled
+                from event receiving from the registry?
+        @@type asynchronous: boolean
         @@ivar reg: Reference to the real, wrapped registry object
         @@type reg: Accessibility.Registry
         @@ivar dev: Reference to the device controller
@@ -79,7 +79,7 @@ class Registry(object):
                 self.app_event_register = None
                 self.desktop = None
 
-                self.main_loop = GObject.MainLoop()
+                self.main_loop = GLib.MainLoop()
 
         def __call__(self):
                 """
@@ -111,28 +111,44 @@ class Registry(object):
 
                 self.has_implementations = True
 
-                # TODO: Move to libatspi
-                _os.environ["AT_SPI_CLIENT"] = "1"
-
-                self.async = False	# not fully supported yet
+                self.asynchronous = False	# not fully supported yet
                 self.started = False
                 self.event_listeners = dict()
 
+        def __getattr__(self, name):
+            """
+            For backwards compatibility with old API
+            """
+            if name == 'async':
+                return self.asynchronous
+            return object.__getattr__(self, name)
+
+        def __setattr__(self, name, value):
+            """
+            For backwards compatibility with old API
+            """
+            if name == 'async':
+                self.asynchronous = value
+            object.__setattr__(self, name, value)
+
         def _set_default_registry (self):
                 self._set_registry (MAIN_LOOP_GLIB)
 
-        def start(self, async=False, gil=True):
+        def start(self, asynchronous=False, gil=True, **kwargs):
                 """
                 Enter the main loop to start receiving and dispatching events.
 
-                @@param async: Should event dispatch be asynchronous (decoupled) from 
-                        event receiving from the AT-SPI registry?
-                @@type async: boolean
+                @@param asynchronous: Should event dispatch be asynchronous
+                        (decoupled) from event receiving from the AT-SPI registry?
+                @@type asynchronous: boolean
                 @@param gil: Add an idle callback which releases the Python GIL for a few
                         milliseconds to allow other threads to run? Necessary if other threads
                         will be used in this process.
                 @@type gil: boolean
                 """
+                if 'async' in kwargs:
+                    # support previous API
+                    asynchronous = kwargs['async']
                 if not self.has_implementations:
                         self._set_default_registry ()
                 self.started = True
@@ -148,9 +164,9 @@ class Registry(object):
                                 return True
                         # make room for an exception if one occurs during the 
                         releaseGIL.keyboard_exception = None
-                        i = GObject.idle_add(releaseGIL)
+                        i = GLib.idle_add(releaseGIL)
                         Atspi.event_main()
-                        GObject.source_remove(i)
+                        GLib.source_remove(i)
                         if releaseGIL.keyboard_exception is not None:
                                 # raise an keyboard exception we may have gotten earlier
                                 raise releaseGIL.keyboard_exception
@@ -250,8 +266,8 @@ class Registry(object):
         # -------------------------------------------------------------------------------
 
         # TODO: Remove this hack
-        _KEY_PRESSED_EVENT=1
-        _KEY_RELEASED_EVENT=2
+        _KEY_PRESSED_EVENT=0
+        _KEY_RELEASED_EVENT=1
 
         def makeSyncType(self, synchronous, preemptive, global_):
                 result = Atspi.KeyListenerSyncType.NOSYNC
@@ -370,7 +386,7 @@ class Registry(object):
                 Generates a keyboard event. One of the keycode or the keysym parameters
                 should be specified and the other should be None. The kind parameter is 
                 required and should be one of the KEY_PRESS, KEY_RELEASE, KEY_PRESSRELEASE,
-                KEY_SYM, or KEY_STRING.
+                KEY_SYM, KEY_STRING, KEY_LOCKMODIFIERS, or KEY_UNLOCKMODIFIERS.
 
                 @@param keycode: Hardware keycode or None
                 @@type keycode: integer
@@ -403,6 +419,23 @@ class Registry(object):
                         self._set_default_registry ()
                 Atspi.generate_mouse_event (x, y, name)
 
+        def setReferenceWIndow(accessible):
+                """
+                Sets the reference window that will be used when
+                generateMouseEvent is called. Coordinates will be assumed to
+                be relative to this window. This * is needed because, due to
+                Wayland's security model, it is not currently possible to
+                possible to retrieve global coordinates.
+                If NULL is passed, then AT-SPI will use the window that has
+                focus at the time that atspi_generate_mouse_event is called.
+
+                @@param accessible: the accessible corresponding to the window
+                to select. should be a top-level window with a role of
+                pyatspi.ROLE_APPLICATION.
+                """
+                if not self.has_implementations:
+                        self._set_default_registry ()
+                Atspi.setReferenceWindow(accessible)
 
         def pumpQueuedEvents (self):
                 """
